"""
Author:  Jacek 'Szumak' Kotlarski --<szumak@virthost.pl>
Created: 2024-05-12

Purpose: Provide shared helper types and mixins leveraged by device
abstractions.

Centralising reusable building blocks keeps device implementations focused on
vendor specific logic while importing from this package for common behaviour.
"""

# #[EOF]#######################################################################
