"""
Author:  Jacek 'Szumak' Kotlarski --<szumak@virthost.pl>
Created: 2024-05-12

Purpose: Collect connector interfaces and implementations used by device
packages.

Importing from this namespace offers a stable entry point for consumers that
need to build or configure network adapters such as the RouterOS API connector.
"""

# #[EOF]#######################################################################
